@@ -3,15 +3,16 @@ $TRANSLATIONS = array(
 "Documents" => "Documentos",
 "Can't create document" => "Não é possível criar o documento",
 "You don't have permission to rename this document" => "Não tem permissão para renomear este documento",
+"File does not exist" => "O ficheiro não existe",
 "Directory saved successfully." => "Diretoria guardada com sucesso.",
-"An error occurred while changing directory." => "Ocorreu um erro ao mudar de diretoria.",
+"An error occurred while changing directory." => "Ocorreu um erro ao mudar de pasta.",
 "Saved" => "Guardado",
 "Format filter server is down or misconfigured" => "O servidor do filtro de formatação está em baixo ou mal configurado",
 "Conversion failed. Check log for details." => "A conversão falhou. Verifique o registo para detalhes.",
 "Saving..." => "A guardar...",
 "Failed to load documents." => "Não foi possível carregar os documentos.",
-"No documents were found. Upload or create a document to get started!" => "Não foram encontrados quaisquer documentos. Envie ou crie um documento para começar!",
-"No connection to server. Trying to reconnect." => "Sem conexão ao servidor. A tentar reconetar.",
+"No documents were found. Upload or create a document to get started!" => "Não foram encontrados quaisquer documentos. Carregue ou crie um documento para começar!",
+"No connection to server. Trying to reconnect." => "Sem conexão ao servidor. A tentar reconectar.",
 "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Ao sair desta página no modo Editor poderá deixar dados não guardados. Em vez disso, é recomendado a utilização do botão 'Fechar'.",
 "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Não foi possível carregar este documento. Por favor, verifique se este pode ser aberto com um editor odt externo. Isto poderá significar que este foi apagado recentemente ou a partilha foi cancelada.",
 "Save" => "Guardar",
