@@ -3,11 +3,12 @@ $TRANSLATIONS = array(
 "Documents" => "เอกสาร",
 "Can't create document" => "ไม่สามารถสร้างเอกสารได้",
 "You don't have permission to rename this document" => "คุณไม่ได้รับอนุญาตให้เปลี่ยนชื่อเอกสารนี้",
+"File does not exist" => "ไม่พบไฟล์ที่นี่",
 "Directory saved successfully." => "บันทึกไดเรกทอรีเรียบร้อยแล้ว",
 "An error occurred while changing directory." => "เกิดข้อผิดพลาดขณะที่เปลี่ยนไดเรกทอรี",
 "Saved" => "บันทึกแล้ว",
 "Format filter server is down or misconfigured" => "ตัวกรองรูปแบบเซิร์ฟเวอร์ล่มหรือตั้งค่าผิดพลาด",
-"Conversion failed. Check log for details." => "การแปลงล้มเหลว ตรวจสอบบันทึกเพื่อดูรายละเอียด",
+"Conversion failed. Check log for details." => "การแปลงไฟล์ล้มเหลว ตรวจสอบบันทึกเพื่อดูรายละเอียด",
 "Saving..." => "กำลังบันทึกข้อมูล...",
 "Failed to load documents." => "ไม่สามารถโหลดเอกสาร",
 "No documents were found. Upload or create a document to get started!" => "ยังไม่มีเอกสารเลย คุณสามารถเริ่มต้นอัพโหลดหรือสร้างเอกสารได้เลย!",
@@ -74,13 +75,13 @@ $TRANSLATIONS = array(
 "Shared with you and the group {group} by {owner}" => "ได้แชร์ให้กับคุณ และกลุ่ม {group} โดย {owner}",
 "Shared with you by {owner}" => "ถูกแชร์ให้กับคุณโดย {owner}",
 "Share with users or groups …" => "แชร์กับผู้ใช้หรือกลุ่ม ...",
-"Share with users, groups or remote users …" => "แชร์กับผู้ใช้กลุ่มหรือผู้ใช้ระยะไกล ...",
+"Share with users, groups or remote users …" => "แชร์กับผู้ใช้หรือกลุ่มหรือผู้ใช้โดยการรีโมท ...",
 "Share" => "แชร์",
 "Share with people on other ownClouds using the syntax username@example.com/owncloud" => "แชร์กับคนใน ownClouds อื่นๆ ที่ใช้ไวยากรณ์ username@example.com/owncloud ",
 "Share link" => "แชร์ลิงค์",
 "The public link will expire no later than {days} days after it is created" => "ลิงค์สาธารณะจะหมดอายุภายใน {days} วัน หลังจากที่มันถูกสร้างขึ้น",
 "Link" => "ลิงค์",
-"Password protect" => "รหัสผ่านป้องกัน",
+"Password protect" => "ป้องกันด้วยรหัสผ่าน",
 "Password" => "รหัสผ่าน",
 "Choose a password for the public link" => "เลือกรหัสผ่านสำหรับลิงค์สาธารณะ",
 "Allow editing" => "อนุญาตให้แก้ไข",
@@ -92,7 +93,7 @@ $TRANSLATIONS = array(
 "An error occured. Please try again" => "เกิดข้อผิดพลาด กรุณาลองอีกครั้ง",
 "Adding user..." => "กำลังเพิ่มผู้ใช้ ...",
 "group" => "กลุ่มผู้ใช้งาน",
-"remote" => "ระยะไกล",
+"remote" => "รีโมท",
 "Resharing is not allowed" => "ไม่อนุญาตให้แชร์ข้อมูลที่ซ้ำกัน",
 "Shared in {item} with {user}" => "ได้แชร์ {item} ให้กับ {user}",
 "Unshare" => "ยกเลิกการแชร์",
